import { CouchbaseHttpApiConfig } from '../../../types';
export declare function requestStatistics(apiConfig: CouchbaseHttpApiConfig, stats: [StatisticDefinition, ...StatisticDefinition[]]): Promise<Response>;
type CouchbaseLabel = 'bucket' | 'scope' | 'collection' | 'index' | 'connection_type';
type GeneralLabel = 'start' | 'end' | 'nodes' | 'nodesAggregation' | 'timeWindow' | 'timeout' | 'alignTimestamps';
type StatisticLabelSelector = {
    /**
     * Label name.
     */
    label: CouchbaseLabel | GeneralLabel | (string & NonNullable<unknown>);
    /**
     * Label value.
     */
    value: string;
    /**
     * Operator used to match the label.
     *
     * @default '='.
     */
    operator?: '=' | '!=' | '=~' | '~=';
};
export type StatisticFunction = 'rate' | 'irate' | 'increase' | 'avg_over_time' | 'min_over_time' | 'max_over_time' | 'deriv' | 'delta' | 'idelta' | 'sum' | 'min' | 'max' | 'avg' | `p${number}`;
export type StatisticDefinition = {
    /**
     * An array of labels that defines the metric to collect.
     */
    metric: [
        Omit<StatisticLabelSelector, 'label'> & {
            label: 'name';
        },
        ...StatisticLabelSelector[]
    ];
    /**
     *
     */
    applyFunctions?: StatisticFunction[];
    /**
     * List of nodes from which data points should be collected.
     *
     * @default All the nodes.
     */
    nodes?: [string, ...string[]];
    /**
     * Whether and how aggregation of retrieved statistics is to be performed.
     *
     * @default No aggregation.
     */
    nodesAggregation?: 'max' | 'min' | 'sum' | 'avg';
    /**
     * Forces data point to be collected on timestamps that are multiple of `10`.
     *
     * @default false
     */
    alignTimestamps?: boolean;
    /**
     * An integer that set by how many seconds each data point is separated.
     *
     * @default 10
     */
    step?: number;
    /**
     * A negative integer that sets when to start the data points, in seconds.
     *
     * @default -60
     */
    start?: number;
    /**
     * A negative integer that sets when to end the data points, in seconds.
     *
     * @default 0
     */
    end?: number;
    /**
     * Statistics collection timeout, in milliseconds.
     *
     * @default 300_000 (5 minutes)
     */
    timeout?: number;
};
type DataPoint = [timestamp: number, value: `${number}`];
type StatisticsResultData = {
    metric: {
        nodes: [string, ...string[]];
        /**
         * Will be undefined if the request parameter `applyFunctions` was not empty.
         */
        instance?: string;
        category?: 'audit' | (string & NonNullable<unknown>);
        /**
         * Will be undefined if the request parameter `applyFunctions` was not empty.
         */
        name?: string;
    } & {
        [label in CouchbaseLabel]?: string;
    };
    values: [DataPoint, ...DataPoint[]];
};
export type StatisticsResult = {
    data: StatisticsResultData[];
    errors: Array<{
        node: string;
        error: string;
    }>;
    /**
     * Timestamp (in seconds) from which data points were collected.
     * Computed from the time of the request and the `start` parameter of the request.
     */
    startTimestamp: number;
    /**
     * Timestamp (in seconds) from which data points were no longer being collected.
     * Computed from the time of the request and the `end` parameter of the request.
     */
    endTimestamp: number;
};
export {};
